@@ -16,7 +16,7 @@
 # ------------------------------------------------------------------
 package Petal::Canonicalizer::XML;
 use Petal::Hash::String;
-use MKDoc::XML::Encode;
+use Petal::XML_Encode_Decode;
 use strict;
 use warnings;
 
@@ -42,7 +42,7 @@ sub process
     
     # grab the <!...> tags which the parser is going to strip
     # in order to reinclude them afterwards
-    # my @decls = $$data_ref =~ /(<!.*?>)/gsm;
+    my @decls = $$data_ref =~ /(<!.*?>)/gsm;
     
     # take the existing processing instructions out and replace
     # them with temporary xml-friendly handlers
@@ -110,10 +110,10 @@ sub _compute_unique_string
 {
     my $class = shift;
     my $data_ref = shift;
-    my $string = '[-' . (join '', map { chr (ord ('a') + int rand 26) } 1..20) . '-]';
+    my $string = '[--' . (join '', map { chr (ord ('a') + int rand 26) } 1..20) . '--]';
     while (index ($$data_ref, $string) >= 0)
     {
-	$string = '[-' . (join '', map { chr (ord ('a') + int rand 26) } 1..20) . '-]';
+	$string = '[--' . (join '', map { chr (ord ('a') + int rand 26) } 1..20) . '--]';
     }
     return $string;
 }
@@ -135,7 +135,7 @@ sub _compute_unique_string
 sub StartTag
 {
     Petal::load_code_generator(); # we will use it later
-    
+
     my $class = shift;
     push @NodeStack, {};
     return if ($class->_is_inside_content_or_replace());
@@ -144,13 +144,12 @@ sub StartTag
     ($tag) = $tag =~ /^<\s*((?:\w|\:|\-)*)/;
     my $att = { %_ };
     
-    $class->_use_macro   ($tag, $att);
-    $class->_on_error    ($tag, $att);
-    $class->_define      ($tag, $att);
-    $class->_condition   ($tag, $att);
-    $class->_repeat      ($tag, $att);    
+    $class->_on_error ($tag, $att);
+    $class->_define ($tag, $att);
+    $class->_condition ($tag, $att);
+    $class->_repeat ($tag, $att);    
     $class->_is_xinclude ($tag) and $class->_xinclude ($tag, $att) and return;
-    $class->_replace     ($tag, $att);
+    $class->_replace ($tag, $att);
     
     my $petal = quotemeta ($Petal::NS);
     
@@ -174,7 +173,7 @@ sub StartTag
 		$command =~ s/^\$//;
 		$command =~ s/^\{//;
 		$command =~ s/\}$//;
-		$command = $class->_encode_backslash_semicolon ($command);
+		$command = Petal::XML_Encode_Decode::encode_backslash_semicolon ($command);
 		$command = "<?var name=\"$command\"?>";
 		$text =~ s/\Q$var\E/$command/g;
 	    }
@@ -300,7 +299,7 @@ sub Text
 	$command =~ s/^\$//;
 	$command =~ s/^\{//;
 	$command =~ s/\}$//;
-	$command = $class->_encode_backslash_semicolon ($command);
+	$command = Petal::XML_Encode_Decode::encode_backslash_semicolon ($command);
 	$command = "<?var name=\"$command\"?>";
 	$text =~ s/\Q$var\E/$command/g;
     }
@@ -318,14 +317,10 @@ sub _is_inside_content_or_replace
     my $endtag = shift;
     my $tmp    = undef;
     $tmp = pop (@NodeStack) if ($endtag);
-    
-    # WHY do I have to do this?
-    return 1 if (defined $tmp and $tmp->{'use-macro'});
     for (my $i=@NodeStack - 1; $i >= 0; $i--)
     {
-	return 1 if ( defined $NodeStack[$i]->{'replace'}   or
-		      defined $NodeStack[$i]->{'content'}   or
-		      defined $NodeStack[$i]->{'use-macro'} );
+	return 1 if ( defined $NodeStack[$i]->{replace} or
+		      defined $NodeStack[$i]->{content} )
     }
     push @NodeStack, $tmp if (defined $tmp);
     return;
@@ -366,7 +361,7 @@ sub _on_error
     my $att   = shift;
     my $expr  = delete $att->{"$petal:on-error"} || return;
     
-    $expr = $class->_encode_backslash_semicolon ($expr);
+    $expr = Petal::XML_Encode_Decode::encode_backslash_semicolon ($expr);
     push @Result, "<?eval?>";
     $NodeStack[$#NodeStack]->{'on-error'} = $expr;
     return 1;
@@ -389,7 +384,7 @@ sub _define
                 delete $att->{"$petal:def"}    ||
                 delete $att->{"$petal:define"} || return;
     
-    $expr = $class->_encode_backslash_semicolon ($expr);
+    $expr = Petal::XML_Encode_Decode::encode_backslash_semicolon ($expr);
     push @Result, map { "<?var name=\"set: $_\"?>" } $class->_split_expression ($expr);
     return 1;
 }
@@ -410,7 +405,7 @@ sub _condition
     my $expr  = delete $att->{"$petal:if"}        ||
                 delete $att->{"$petal:condition"} || return;
     
-    $expr = $class->_encode_backslash_semicolon ($expr);
+    $expr = Petal::XML_Encode_Decode::encode_backslash_semicolon ($expr);
     my @new = map { "<?if name=\"$_\"?>" } $class->_split_expression ($expr);
     push @Result, @new;
     $NodeStack[$#NodeStack]->{condition} = scalar @new;
@@ -439,7 +434,7 @@ sub _repeat
     my @new = ();
     foreach $expr (@exprs)
     {
-	$expr = $class->_encode_backslash_semicolon ($expr);
+	$expr = Petal::XML_Encode_Decode::encode_backslash_semicolon ($expr);
 	push @new, "<?for name=\"$expr\"?>"
     }
     push @Result, @new;
@@ -464,7 +459,7 @@ sub _replace
                delete $att->{"$petal:outer"}   || return;
     
     my @new = map {
-	$_ = $class->_encode_backslash_semicolon ($_);
+	$_ = Petal::XML_Encode_Decode::encode_backslash_semicolon ($_);
 	"<?var name=\"$_\"?>";
     } split /(\s|\r|\n)*\;(\s|\r|\n)*/ms, $expr;
     
@@ -474,27 +469,6 @@ sub _replace
 }
 
 
-# _use_macro;
-# -----------
-# Rewrites <tag use-macro="something" as <?include file="something"?>
-# All the descendent nodes of 'tag' will be skipped
-sub _use_macro
-{
-    my $class = shift;
-    return if ($class->_is_inside_content_or_replace());
-    
-    my $metal = $Petal::MT_NS;
-    
-    my $tag = shift;
-    my $att = shift;
-    my $expr = delete $att->{"$metal:use-macro"} || return;
-    
-    push @Result, qq|<?include file="$expr"?>|;
-    $NodeStack[$#NodeStack]->{'use-macro'} = 'true';
-    return 1;
-}
-
-
 # _attributes;
 # ------------
 # Rewrites <?tag attributes="[name1] [expression]"?>
@@ -517,7 +491,7 @@ sub _attributes
 	next unless (defined $string);
 	next if ($string =~ /^\s*$/);
 	my ($attr, $expr) = $string =~ /^\s*((?:\w|\:)+)\s+(.*?)\s*$/;
-	$expr = $class->_encode_backslash_semicolon ($expr);
+	$expr = Petal::XML_Encode_Decode::encode_backslash_semicolon ($expr);
 	$att->{$attr} = "<?attr name=\"$attr\" value=\"$expr\"?>";
     }
     return 1;
@@ -540,7 +514,7 @@ sub _content
                delete $att->{"$petal:contents"} ||
 	       delete $att->{"$petal:inner"}    || return;
     my @new = map {
-	$_ = $class->_encode_backslash_semicolon ($_);
+	$_ = Petal::XML_Encode_Decode::encode_backslash_semicolon ($_);
 	"<?var name=\"$_\"?>";
     } $class->_split_expression ($expr);
     push @Result, @new;
@@ -568,7 +542,7 @@ sub _xinclude
 	$att = { map { $_ =~ /^$petal:/ ? () : $_ => $att->{$_} } keys %{$att} };
 	
 	my $expr = delete $att->{'href'};
-	$expr = $class->_encode_backslash_semicolon ($expr);
+	$expr = Petal::XML_Encode_Decode::encode_backslash_semicolon ($expr);
 	push @Result, "<?include file=\"$expr\"?>";
     }
     return 1;
@@ -588,15 +562,6 @@ sub _is_xinclude
 }
 
 
-sub _encode_backslash_semicolon
-{
-    my $class = shift;
-    my $data  = shift;
-    $data =~ s/($MKDoc::XML::Encode::XML_Encode_Pattern)/&$MKDoc::XML::Encode::XML_Encode{$1}\\;/go;
-    return $data;
-}
-
-
 1;
 
 
